class FakeKey():
  """Fake of google.cloud.datastore.Key."""

  def _flat_path(self):
    return "FakeFlatPath"


class FakeDataStoreClient():
  """Fake of google.cloud.datastore.Client."""

  def __init__(self):
    self._start_failing = False

  def key(self, *path_args, **kwargs):
    return FakeKey()

  def put(self, entity):
    if self._start_failing:
      raise ValueError('Value error')

    self.entity = entity

  def start_failing(self):
    self._start_failing = True



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from proto import market_transaction_model_pb2 as proto_dot_market__transaction__model__pb2


class MarketTransactionModelStub(object):
  """The market transaction model service definition.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.PredictLimitPrice = channel.unary_unary(
        '/org.powertac.samplebroker.MarketTransactionModel/PredictLimitPrice',
        request_serializer=proto_dot_market__transaction__model__pb2.PredictLimitPriceRequest.SerializeToString,
        response_deserializer=proto_dot_market__transaction__model__pb2.PredictLimitPriceResponse.FromString,
        )
    self.PutStateHistory = channel.unary_unary(
        '/org.powertac.samplebroker.MarketTransactionModel/PutStateHistory',
        request_serializer=proto_dot_market__transaction__model__pb2.PutStateHistoryRequest.SerializeToString,
        response_deserializer=proto_dot_market__transaction__model__pb2.PutStateHistoryResponse.FromString,
        )


class MarketTransactionModelServicer(object):
  """The market transaction model service definition.
  """

  def PredictLimitPrice(self, request, context):
    """Send a request to predict current states
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def PutStateHistory(self, request, context):
    """TODO
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_MarketTransactionModelServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'PredictLimitPrice': grpc.unary_unary_rpc_method_handler(
          servicer.PredictLimitPrice,
          request_deserializer=proto_dot_market__transaction__model__pb2.PredictLimitPriceRequest.FromString,
          response_serializer=proto_dot_market__transaction__model__pb2.PredictLimitPriceResponse.SerializeToString,
      ),
      'PutStateHistory': grpc.unary_unary_rpc_method_handler(
          servicer.PutStateHistory,
          request_deserializer=proto_dot_market__transaction__model__pb2.PutStateHistoryRequest.FromString,
          response_serializer=proto_dot_market__transaction__model__pb2.PutStateHistoryResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'org.powertac.samplebroker.MarketTransactionModel', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from proto import data_logger_service_pb2 as proto_dot_data__logger__service__pb2


class DataLoggerServiceStub(object):
  """The service that provides an endpoint to store various entities to Google
  Cloud Data Store.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.PutCompetition = channel.unary_unary(
        '/org.powertac.samplebroker.api.DataLoggerService/PutCompetition',
        request_serializer=proto_dot_data__logger__service__pb2.PutCompetitionRequest.SerializeToString,
        response_deserializer=proto_dot_data__logger__service__pb2.PutCompetitionResponse.FromString,
        )


class DataLoggerServiceServicer(object):
  """The service that provides an endpoint to store various entities to Google
  Cloud Data Store.
  """

  def PutCompetition(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_DataLoggerServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'PutCompetition': grpc.unary_unary_rpc_method_handler(
          servicer.PutCompetition,
          request_deserializer=proto_dot_data__logger__service__pb2.PutCompetitionRequest.FromString,
          response_serializer=proto_dot_data__logger__service__pb2.PutCompetitionResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'org.powertac.samplebroker.api.DataLoggerService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/market_transaction_model.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/market_transaction_model.proto',
  package='org.powertac.samplebroker',
  syntax='proto3',
  serialized_pb=_b('\n$proto/market_transaction_model.proto\x12\x19org.powertac.samplebroker\"e\n\x18PredictLimitPriceRequest\x12I\n\x05state\x18\x01 \x01(\x0b\x32:.org.powertac.samplebroker.WholesaleMarketEnvironmentState\"0\n\x19PredictLimitPriceResponse\x12\x13\n\x0blimit_price\x18\x01 \x01(\x01\"\xff\x01\n\x16PutStateHistoryRequest\x12I\n\x05state\x18\x01 \x01(\x0b\x32:.org.powertac.samplebroker.WholesaleMarketEnvironmentState\x12M\n\tnew_state\x18\x02 \x01(\x0b\x32:.org.powertac.samplebroker.WholesaleMarketEnvironmentState\x12\x1d\n\x15predicted_limit_price\x18\x03 \x01(\x01\x12\x1b\n\x13\x63leared_limit_price\x18\x04 \x01(\x01\x12\x0f\n\x07\x63leared\x18\x05 \x01(\x08\"\x19\n\x17PutStateHistoryResponse\"\x93\x01\n\x1fWholesaleMarketEnvironmentState\x12\x13\n\x0bhour_of_day\x18\x01 \x01(\x05\x12\x13\n\x0b\x64\x61y_of_week\x18\x02 \x01(\x05\x12\"\n\x1ahour_of_day_for_prediction\x18\x03 \x01(\x05\x12\"\n\x1a\x64\x61y_of_week_for_prediction\x18\x04 \x01(\x05\x32\x97\x02\n\x16MarketTransactionModel\x12\x80\x01\n\x11PredictLimitPrice\x12\x33.org.powertac.samplebroker.PredictLimitPriceRequest\x1a\x34.org.powertac.samplebroker.PredictLimitPriceResponse\"\x00\x12z\n\x0fPutStateHistory\x12\x31.org.powertac.samplebroker.PutStateHistoryRequest\x1a\x32.org.powertac.samplebroker.PutStateHistoryResponse\"\x00\x42\x36\n\x19org.powertac.samplebrokerB\x11MarketTransactionP\x01\xa2\x02\x03\x42UNb\x06proto3')
)




_PREDICTLIMITPRICEREQUEST = _descriptor.Descriptor(
  name='PredictLimitPriceRequest',
  full_name='org.powertac.samplebroker.PredictLimitPriceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='org.powertac.samplebroker.PredictLimitPriceRequest.state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=168,
)


_PREDICTLIMITPRICERESPONSE = _descriptor.Descriptor(
  name='PredictLimitPriceResponse',
  full_name='org.powertac.samplebroker.PredictLimitPriceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='limit_price', full_name='org.powertac.samplebroker.PredictLimitPriceResponse.limit_price', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=170,
  serialized_end=218,
)


_PUTSTATEHISTORYREQUEST = _descriptor.Descriptor(
  name='PutStateHistoryRequest',
  full_name='org.powertac.samplebroker.PutStateHistoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='org.powertac.samplebroker.PutStateHistoryRequest.state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='new_state', full_name='org.powertac.samplebroker.PutStateHistoryRequest.new_state', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='predicted_limit_price', full_name='org.powertac.samplebroker.PutStateHistoryRequest.predicted_limit_price', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cleared_limit_price', full_name='org.powertac.samplebroker.PutStateHistoryRequest.cleared_limit_price', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cleared', full_name='org.powertac.samplebroker.PutStateHistoryRequest.cleared', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=476,
)


_PUTSTATEHISTORYRESPONSE = _descriptor.Descriptor(
  name='PutStateHistoryResponse',
  full_name='org.powertac.samplebroker.PutStateHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=478,
  serialized_end=503,
)


_WHOLESALEMARKETENVIRONMENTSTATE = _descriptor.Descriptor(
  name='WholesaleMarketEnvironmentState',
  full_name='org.powertac.samplebroker.WholesaleMarketEnvironmentState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hour_of_day', full_name='org.powertac.samplebroker.WholesaleMarketEnvironmentState.hour_of_day', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='day_of_week', full_name='org.powertac.samplebroker.WholesaleMarketEnvironmentState.day_of_week', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hour_of_day_for_prediction', full_name='org.powertac.samplebroker.WholesaleMarketEnvironmentState.hour_of_day_for_prediction', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='day_of_week_for_prediction', full_name='org.powertac.samplebroker.WholesaleMarketEnvironmentState.day_of_week_for_prediction', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=506,
  serialized_end=653,
)

_PREDICTLIMITPRICEREQUEST.fields_by_name['state'].message_type = _WHOLESALEMARKETENVIRONMENTSTATE
_PUTSTATEHISTORYREQUEST.fields_by_name['state'].message_type = _WHOLESALEMARKETENVIRONMENTSTATE
_PUTSTATEHISTORYREQUEST.fields_by_name['new_state'].message_type = _WHOLESALEMARKETENVIRONMENTSTATE
DESCRIPTOR.message_types_by_name['PredictLimitPriceRequest'] = _PREDICTLIMITPRICEREQUEST
DESCRIPTOR.message_types_by_name['PredictLimitPriceResponse'] = _PREDICTLIMITPRICERESPONSE
DESCRIPTOR.message_types_by_name['PutStateHistoryRequest'] = _PUTSTATEHISTORYREQUEST
DESCRIPTOR.message_types_by_name['PutStateHistoryResponse'] = _PUTSTATEHISTORYRESPONSE
DESCRIPTOR.message_types_by_name['WholesaleMarketEnvironmentState'] = _WHOLESALEMARKETENVIRONMENTSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PredictLimitPriceRequest = _reflection.GeneratedProtocolMessageType('PredictLimitPriceRequest', (_message.Message,), dict(
  DESCRIPTOR = _PREDICTLIMITPRICEREQUEST,
  __module__ = 'proto.market_transaction_model_pb2'
  # @@protoc_insertion_point(class_scope:org.powertac.samplebroker.PredictLimitPriceRequest)
  ))
_sym_db.RegisterMessage(PredictLimitPriceRequest)

PredictLimitPriceResponse = _reflection.GeneratedProtocolMessageType('PredictLimitPriceResponse', (_message.Message,), dict(
  DESCRIPTOR = _PREDICTLIMITPRICERESPONSE,
  __module__ = 'proto.market_transaction_model_pb2'
  # @@protoc_insertion_point(class_scope:org.powertac.samplebroker.PredictLimitPriceResponse)
  ))
_sym_db.RegisterMessage(PredictLimitPriceResponse)

PutStateHistoryRequest = _reflection.GeneratedProtocolMessageType('PutStateHistoryRequest', (_message.Message,), dict(
  DESCRIPTOR = _PUTSTATEHISTORYREQUEST,
  __module__ = 'proto.market_transaction_model_pb2'
  # @@protoc_insertion_point(class_scope:org.powertac.samplebroker.PutStateHistoryRequest)
  ))
_sym_db.RegisterMessage(PutStateHistoryRequest)

PutStateHistoryResponse = _reflection.GeneratedProtocolMessageType('PutStateHistoryResponse', (_message.Message,), dict(
  DESCRIPTOR = _PUTSTATEHISTORYRESPONSE,
  __module__ = 'proto.market_transaction_model_pb2'
  # @@protoc_insertion_point(class_scope:org.powertac.samplebroker.PutStateHistoryResponse)
  ))
_sym_db.RegisterMessage(PutStateHistoryResponse)

WholesaleMarketEnvironmentState = _reflection.GeneratedProtocolMessageType('WholesaleMarketEnvironmentState', (_message.Message,), dict(
  DESCRIPTOR = _WHOLESALEMARKETENVIRONMENTSTATE,
  __module__ = 'proto.market_transaction_model_pb2'
  # @@protoc_insertion_point(class_scope:org.powertac.samplebroker.WholesaleMarketEnvironmentState)
  ))
_sym_db.RegisterMessage(WholesaleMarketEnvironmentState)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\031org.powertac.samplebrokerB\021MarketTransactionP\001\242\002\003BUN'))

_MARKETTRANSACTIONMODEL = _descriptor.ServiceDescriptor(
  name='MarketTransactionModel',
  full_name='org.powertac.samplebroker.MarketTransactionModel',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=656,
  serialized_end=935,
  methods=[
  _descriptor.MethodDescriptor(
    name='PredictLimitPrice',
    full_name='org.powertac.samplebroker.MarketTransactionModel.PredictLimitPrice',
    index=0,
    containing_service=None,
    input_type=_PREDICTLIMITPRICEREQUEST,
    output_type=_PREDICTLIMITPRICERESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PutStateHistory',
    full_name='org.powertac.samplebroker.MarketTransactionModel.PutStateHistory',
    index=1,
    containing_service=None,
    input_type=_PUTSTATEHISTORYREQUEST,
    output_type=_PUTSTATEHISTORYRESPONSE,
    options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_MARKETTRANSACTIONMODEL)

DESCRIPTOR.services_by_name['MarketTransactionModel'] = _MARKETTRANSACTIONMODEL

try:
  # THESE ELEMENTS WILL BE DEPRECATED.
  # Please use the generated *_pb2_grpc.py files instead.
  import grpc
  from grpc.beta import implementations as beta_implementations
  from grpc.beta import interfaces as beta_interfaces
  from grpc.framework.common import cardinality
  from grpc.framework.interfaces.face import utilities as face_utilities


  class MarketTransactionModelStub(object):
    """The market transaction model service definition.
    """

    def __init__(self, channel):
      """Constructor.

      Args:
        channel: A grpc.Channel.
      """
      self.PredictLimitPrice = channel.unary_unary(
          '/org.powertac.samplebroker.MarketTransactionModel/PredictLimitPrice',
          request_serializer=PredictLimitPriceRequest.SerializeToString,
          response_deserializer=PredictLimitPriceResponse.FromString,
          )
      self.PutStateHistory = channel.unary_unary(
          '/org.powertac.samplebroker.MarketTransactionModel/PutStateHistory',
          request_serializer=PutStateHistoryRequest.SerializeToString,
          response_deserializer=PutStateHistoryResponse.FromString,
          )


  class MarketTransactionModelServicer(object):
    """The market transaction model service definition.
    """

    def PredictLimitPrice(self, request, context):
      """Send a request to predict current states
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def PutStateHistory(self, request, context):
      """TODO
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')


  def add_MarketTransactionModelServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'PredictLimitPrice': grpc.unary_unary_rpc_method_handler(
            servicer.PredictLimitPrice,
            request_deserializer=PredictLimitPriceRequest.FromString,
            response_serializer=PredictLimitPriceResponse.SerializeToString,
        ),
        'PutStateHistory': grpc.unary_unary_rpc_method_handler(
            servicer.PutStateHistory,
            request_deserializer=PutStateHistoryRequest.FromString,
            response_serializer=PutStateHistoryResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        'org.powertac.samplebroker.MarketTransactionModel', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


  class BetaMarketTransactionModelServicer(object):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This class was generated
    only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0."""
    """The market transaction model service definition.
    """
    def PredictLimitPrice(self, request, context):
      """Send a request to predict current states
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def PutStateHistory(self, request, context):
      """TODO
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)


  class BetaMarketTransactionModelStub(object):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This class was generated
    only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0."""
    """The market transaction model service definition.
    """
    def PredictLimitPrice(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """Send a request to predict current states
      """
      raise NotImplementedError()
    PredictLimitPrice.future = None
    def PutStateHistory(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """TODO
      """
      raise NotImplementedError()
    PutStateHistory.future = None


  def beta_create_MarketTransactionModel_server(servicer, pool=None, pool_size=None, default_timeout=None, maximum_timeout=None):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This function was
    generated only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0"""
    request_deserializers = {
      ('org.powertac.samplebroker.MarketTransactionModel', 'PredictLimitPrice'): PredictLimitPriceRequest.FromString,
      ('org.powertac.samplebroker.MarketTransactionModel', 'PutStateHistory'): PutStateHistoryRequest.FromString,
    }
    response_serializers = {
      ('org.powertac.samplebroker.MarketTransactionModel', 'PredictLimitPrice'): PredictLimitPriceResponse.SerializeToString,
      ('org.powertac.samplebroker.MarketTransactionModel', 'PutStateHistory'): PutStateHistoryResponse.SerializeToString,
    }
    method_implementations = {
      ('org.powertac.samplebroker.MarketTransactionModel', 'PredictLimitPrice'): face_utilities.unary_unary_inline(servicer.PredictLimitPrice),
      ('org.powertac.samplebroker.MarketTransactionModel', 'PutStateHistory'): face_utilities.unary_unary_inline(servicer.PutStateHistory),
    }
    server_options = beta_implementations.server_options(request_deserializers=request_deserializers, response_serializers=response_serializers, thread_pool=pool, thread_pool_size=pool_size, default_timeout=default_timeout, maximum_timeout=maximum_timeout)
    return beta_implementations.server(method_implementations, options=server_options)


  def beta_create_MarketTransactionModel_stub(channel, host=None, metadata_transformer=None, pool=None, pool_size=None):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This function was
    generated only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0"""
    request_serializers = {
      ('org.powertac.samplebroker.MarketTransactionModel', 'PredictLimitPrice'): PredictLimitPriceRequest.SerializeToString,
      ('org.powertac.samplebroker.MarketTransactionModel', 'PutStateHistory'): PutStateHistoryRequest.SerializeToString,
    }
    response_deserializers = {
      ('org.powertac.samplebroker.MarketTransactionModel', 'PredictLimitPrice'): PredictLimitPriceResponse.FromString,
      ('org.powertac.samplebroker.MarketTransactionModel', 'PutStateHistory'): PutStateHistoryResponse.FromString,
    }
    cardinalities = {
      'PredictLimitPrice': cardinality.Cardinality.UNARY_UNARY,
      'PutStateHistory': cardinality.Cardinality.UNARY_UNARY,
    }
    stub_options = beta_implementations.stub_options(host=host, metadata_transformer=metadata_transformer, request_serializers=request_serializers, response_deserializers=response_deserializers, thread_pool=pool, thread_pool_size=pool_size)
    return beta_implementations.dynamic_stub(channel, 'org.powertac.samplebroker.MarketTransactionModel', cardinalities, options=stub_options)
except ImportError:
  pass
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/competition.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/competition.proto',
  package='org.powertac.samplebroker.api',
  syntax='proto3',
  serialized_pb=_b('\n\x17proto/competition.proto\x12\x1dorg.powertac.samplebroker.api\"\xbd\x02\n\x0b\x43ompetition\x12\x16\n\x0e\x63ompetition_id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1c\n\x14minimumTimeslotCount\x18\x03 \x01(\x05\x12\x1d\n\x15\x65xpectedTimeslotCount\x18\x04 \x01(\x05\x12\x1c\n\x14minimumOrderQuantity\x18\x05 \x01(\x01\x12#\n\x1bmaxUpRegulationPaymentRatio\x18\x06 \x01(\x01\x12\x1c\n\x14upRegulationDiscount\x18\x07 \x01(\x01\x12%\n\x1dmaxDownRegulationPaymentRatio\x18\x08 \x01(\x01\x12\x1e\n\x16\x64ownRegulationDiscount\x18\t \x01(\x01\x12#\n\x1b\x65stimatedConsumptionPremium\x18\n \x01(\x01\x62\x06proto3')
)




_COMPETITION = _descriptor.Descriptor(
  name='Competition',
  full_name='org.powertac.samplebroker.api.Competition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='competition_id', full_name='org.powertac.samplebroker.api.Competition.competition_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='org.powertac.samplebroker.api.Competition.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='minimumTimeslotCount', full_name='org.powertac.samplebroker.api.Competition.minimumTimeslotCount', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='expectedTimeslotCount', full_name='org.powertac.samplebroker.api.Competition.expectedTimeslotCount', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='minimumOrderQuantity', full_name='org.powertac.samplebroker.api.Competition.minimumOrderQuantity', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='maxUpRegulationPaymentRatio', full_name='org.powertac.samplebroker.api.Competition.maxUpRegulationPaymentRatio', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='upRegulationDiscount', full_name='org.powertac.samplebroker.api.Competition.upRegulationDiscount', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='maxDownRegulationPaymentRatio', full_name='org.powertac.samplebroker.api.Competition.maxDownRegulationPaymentRatio', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='downRegulationDiscount', full_name='org.powertac.samplebroker.api.Competition.downRegulationDiscount', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='estimatedConsumptionPremium', full_name='org.powertac.samplebroker.api.Competition.estimatedConsumptionPremium', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=59,
  serialized_end=376,
)

DESCRIPTOR.message_types_by_name['Competition'] = _COMPETITION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Competition = _reflection.GeneratedProtocolMessageType('Competition', (_message.Message,), dict(
  DESCRIPTOR = _COMPETITION,
  __module__ = 'proto.competition_pb2'
  # @@protoc_insertion_point(class_scope:org.powertac.samplebroker.api.Competition)
  ))
_sym_db.RegisterMessage(Competition)


try:
  # THESE ELEMENTS WILL BE DEPRECATED.
  # Please use the generated *_pb2_grpc.py files instead.
  import grpc
  from grpc.beta import implementations as beta_implementations
  from grpc.beta import interfaces as beta_interfaces
  from grpc.framework.common import cardinality
  from grpc.framework.interfaces.face import utilities as face_utilities
except ImportError:
  pass
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/simulation_job.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/simulation_job.proto',
  package='org.powertac.samplebroker.bunnieinfra',
  syntax='proto3',
  serialized_pb=_b('\n\x1aproto/simulation_job.proto\x12%org.powertac.samplebroker.bunnieinfra\"\x90\x04\n\rSimulationJob\x12K\n\x06status\x18\x01 \x01(\x0e\x32;.org.powertac.samplebroker.bunnieinfra.SimulationJob.Status\x12L\n\x07\x62rokers\x18\x02 \x03(\x0b\x32;.org.powertac.samplebroker.bunnieinfra.SimulationJob.Broker\x12Z\n\x0e\x62ootstrap_file\x18\x03 \x01(\x0b\x32\x42.org.powertac.samplebroker.bunnieinfra.SimulationJob.BootstrapFile\x12\x15\n\rexperiment_id\x18\x04 \x01(\x03\x1a,\n\x06\x42roker\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x64ocker_image\x18\x02 \x01(\t\x1aV\n\rBootstrapFile\x12(\n google_cloud_storage_bucket_name\x18\x01 \x01(\t\x12\x1b\n\x13\x62ootstrap_file_path\x18\x02 \x01(\t\"k\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\x10\n\x0cSTATUS_READY\x10\x01\x12\x12\n\x0eSTATUS_RUNNING\x10\x02\x12\x14\n\x10STATUS_COMPLETED\x10\x03\x12\x11\n\rSTATUS_FAILED\x10\x04\x62\x06proto3')
)



_SIMULATIONJOB_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='org.powertac.samplebroker.bunnieinfra.SimulationJob.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNKNOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STATUS_READY', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STATUS_RUNNING', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STATUS_COMPLETED', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STATUS_FAILED', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=491,
  serialized_end=598,
)
_sym_db.RegisterEnumDescriptor(_SIMULATIONJOB_STATUS)


_SIMULATIONJOB_BROKER = _descriptor.Descriptor(
  name='Broker',
  full_name='org.powertac.samplebroker.bunnieinfra.SimulationJob.Broker',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='org.powertac.samplebroker.bunnieinfra.SimulationJob.Broker.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='docker_image', full_name='org.powertac.samplebroker.bunnieinfra.SimulationJob.Broker.docker_image', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=357,
  serialized_end=401,
)

_SIMULATIONJOB_BOOTSTRAPFILE = _descriptor.Descriptor(
  name='BootstrapFile',
  full_name='org.powertac.samplebroker.bunnieinfra.SimulationJob.BootstrapFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='google_cloud_storage_bucket_name', full_name='org.powertac.samplebroker.bunnieinfra.SimulationJob.BootstrapFile.google_cloud_storage_bucket_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bootstrap_file_path', full_name='org.powertac.samplebroker.bunnieinfra.SimulationJob.BootstrapFile.bootstrap_file_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=403,
  serialized_end=489,
)

_SIMULATIONJOB = _descriptor.Descriptor(
  name='SimulationJob',
  full_name='org.powertac.samplebroker.bunnieinfra.SimulationJob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='org.powertac.samplebroker.bunnieinfra.SimulationJob.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='brokers', full_name='org.powertac.samplebroker.bunnieinfra.SimulationJob.brokers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bootstrap_file', full_name='org.powertac.samplebroker.bunnieinfra.SimulationJob.bootstrap_file', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='experiment_id', full_name='org.powertac.samplebroker.bunnieinfra.SimulationJob.experiment_id', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_SIMULATIONJOB_BROKER, _SIMULATIONJOB_BOOTSTRAPFILE, ],
  enum_types=[
    _SIMULATIONJOB_STATUS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=598,
)

_SIMULATIONJOB_BROKER.containing_type = _SIMULATIONJOB
_SIMULATIONJOB_BOOTSTRAPFILE.containing_type = _SIMULATIONJOB
_SIMULATIONJOB.fields_by_name['status'].enum_type = _SIMULATIONJOB_STATUS
_SIMULATIONJOB.fields_by_name['brokers'].message_type = _SIMULATIONJOB_BROKER
_SIMULATIONJOB.fields_by_name['bootstrap_file'].message_type = _SIMULATIONJOB_BOOTSTRAPFILE
_SIMULATIONJOB_STATUS.containing_type = _SIMULATIONJOB
DESCRIPTOR.message_types_by_name['SimulationJob'] = _SIMULATIONJOB
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SimulationJob = _reflection.GeneratedProtocolMessageType('SimulationJob', (_message.Message,), dict(

  Broker = _reflection.GeneratedProtocolMessageType('Broker', (_message.Message,), dict(
    DESCRIPTOR = _SIMULATIONJOB_BROKER,
    __module__ = 'proto.simulation_job_pb2'
    # @@protoc_insertion_point(class_scope:org.powertac.samplebroker.bunnieinfra.SimulationJob.Broker)
    ))
  ,

  BootstrapFile = _reflection.GeneratedProtocolMessageType('BootstrapFile', (_message.Message,), dict(
    DESCRIPTOR = _SIMULATIONJOB_BOOTSTRAPFILE,
    __module__ = 'proto.simulation_job_pb2'
    # @@protoc_insertion_point(class_scope:org.powertac.samplebroker.bunnieinfra.SimulationJob.BootstrapFile)
    ))
  ,
  DESCRIPTOR = _SIMULATIONJOB,
  __module__ = 'proto.simulation_job_pb2'
  # @@protoc_insertion_point(class_scope:org.powertac.samplebroker.bunnieinfra.SimulationJob)
  ))
_sym_db.RegisterMessage(SimulationJob)
_sym_db.RegisterMessage(SimulationJob.Broker)
_sym_db.RegisterMessage(SimulationJob.BootstrapFile)


try:
  # THESE ELEMENTS WILL BE DEPRECATED.
  # Please use the generated *_pb2_grpc.py files instead.
  import grpc
  from grpc.beta import implementations as beta_implementations
  from grpc.beta import interfaces as beta_interfaces
  from grpc.framework.common import cardinality
  from grpc.framework.interfaces.face import utilities as face_utilities
except ImportError:
  pass
# @@protoc_insertion_point(module_scope)
